@@ -1,6 +1,6 @@
 package XTaTIK;
 
-our $VERSION = '0.002001'; # VERSION
+our $VERSION = '0.003001'; # VERSION
 
 use Mojo::Base 'Mojolicious';
 
@@ -17,6 +17,8 @@ use File::Spec::Functions qw/catfile  curdir  catdir  rel2abs/;
 use Carp qw/croak/;
 use HTML::Entities;
 use Mojo::Pg;
+use experimental qw/postderef/;
+use lib;
 
 my $PG;
 
@@ -32,13 +34,17 @@ sub startup {
 
     if ( $ENV{XTATIK_COMPANY} ) {
         unshift @{ $self->renderer->paths },
-            catfile $ENV{XTATIK_COMPANY}, 'templates';
+            catdir $ENV{XTATIK_COMPANY}, 'templates';
 
         unshift @{ $self->static->paths },
-            catfile $ENV{XTATIK_COMPANY}, 'public';
+            catdir $ENV{XTATIK_COMPANY}, 'public';
 
         unshift @sass_path,
-            catfile $ENV{XTATIK_COMPANY}, 'public', 'sass';
+            catdir $ENV{XTATIK_COMPANY}, 'public', 'sass';
+
+        lib->import( catdir $ENV{XTATIK_COMPANY}, 'lib' );
+
+        blasdsdasdsa->import;
     }
 
     unshift @sass_path,
@@ -54,13 +60,14 @@ sub startup {
     $self->config('_silo_path', $silo_path);
 
     unshift @{ $self->renderer->paths },
-            catfile $silo_path, 'templates';
+            catdir $silo_path, 'templates';
 
     unshift @{ $self->static->paths },
-        catfile $silo_path, 'public';
+        catdir $silo_path, 'public';
 
     unshift @sass_path,
-        catfile $silo_path, 'public', 'sass';
+        catdir $silo_path, 'public', 'sass';
+    lib->import( catdir $silo_path, 'lib' );
 
     unshift @sass_path,
             catdir rel2abs(curdir), qw/lib XTaTIK public  sass  fake-site/
@@ -75,6 +82,9 @@ sub startup {
     $self->log->debug("XTATIK_SITE_ROOT: $ENV{XTATIK_SITE_ROOT}");
     $self->log->debug("Silo path: $silo_path");
     $self->log->debug("SASS path: $ENV{SASS_PATH}");
+    $self->log->debug("Database: "
+      . (($self->config('pg_url') =~ m{^(?:postgresql:///)?(\w+)}i)[0] //'')
+    );
     $self->log->debug('**********************');
 
     $self->secrets([ $self->config('mojo_secrets') ]);
@@ -200,10 +210,18 @@ sub startup {
     { # Cart routes
         my $rc = $r->under('/cart');
         $rc->get( '/'               )->to('cart#index'          );
-        $rc->any( '/thank-you'      )->to('cart#thank_you'      );
         $rc->post('/add'            )->to('cart#add'            );
-        $rc->post('/checkout'       )->to('cart#checkout'       );
-        $rc->post('/checkout-review')->to('cart#checkout_review');
+
+        for my $plug ( $self->config('checkout_system')->@* ) {
+            my ( $name, $conf ) = ref $plug ? ( @$plug ) : ( $plug );
+
+            my $handler = "XTaTIK::Plugin::Cart::$name";
+            eval "require $handler"
+                or die "Failed to load cart handler $handler: $@";
+
+            my $h = $handler->new( $conf ? ( conf => $conf ) : () );
+            $h->_add_routes( $rc );
+        }
     }
 
     unless ( $self->config('no_blog') ) {
@@ -566,9 +584,27 @@ to C<bug-XTaTIK at rt.cpan.org>
 
 =head1 LICENSE
 
+    Copyright © 2015, Zoffix Znet
+
 You can use and distribute this module under
 The Artistic License 2.0.
 See the C<LICENSE> file included in this distribution for complete
 details.
 
+B<Note:> for convenience of distribution, this module includes works
+created by other organizations. They retain their copyright and their
+original licenses:
+
+=head2 Bootstrap3
+
+    Copyright © 2011-2015, Twitter, Inc
+
+L<http://getbootstrap.com/>. Licensed under the L<MIT License|https://github.com/twbs/bootstrap/blob/master/LICENSE>
+
+=head2 jQuery
+
+    Copyright © 2005, 2015 jQuery Foundation, Inc.
+
+L<https://jquery.org>. Licensed under the L<MIT License|https://tldrlegal.com/license/mit-license>
+
 =cut
\ No newline at end of file
